using RealityStack.IO.Base;
using UnityEngine;

namespace RealityStack.OTSS.DigitalInk
{
    public class DigitalInkInteraction : MonoBehaviour
    {
        public XRSource xrSource;
        public DigitalInkManager sketchingManager;

        public bool pressureSensitiveTip = true;
        public ControllerButton controllerButton = ControllerButton.None;
        public HandGestures handGesture = HandGestures.Unknown;

        private IControllerInput _controllerInput;
        private IHandGesture _handGesture;
        private IControllerTracking _controllerTracking;

        void Update()
        {
            _controllerInput ??= RSIO.ControllerInput(this);
            _handGesture ??= RSIO.HandGesture(this);
            sketchingManager ??= GetComponent<DigitalInkManager>();

            if (sketchingManager != null)
            {
                sketchingManager.isActive = pressureSensitiveTip && _controllerInput != null && _controllerInput.Get(xrSource, ControllerAxis1D.PrimaryStylusForce) > 0f;

                if (controllerButton != ControllerButton.None)
                    sketchingManager.isActive |= _controllerInput != null && _controllerInput.Get(xrSource, controllerButton);

                if (handGesture != HandGestures.Unknown)
                    sketchingManager.isActive |= _handGesture != null && _handGesture.Get(xrSource, handGesture);
            }
        }
    }
}